@@ -8,8 +8,6 @@ from djangoldp_community.models import Community
 class ModelTestCase(APITestCase):
     def setUp(self):
         self.client = APIClient()
-        LDListMixin.to_representation_cache.reset()
-        LDPSerializer.to_representation_cache.reset()
 
     # I should not be able to create duplicate names in local communities
     def test_cant_create_duplicate_local_communities(self):
