@@ -31,10 +31,10 @@ class CommunityMembersViewset(LDPViewSet):
 class OpenCommunitiesViewset(LDPViewSet):
   def get_queryset(self):
     queryset = super().get_queryset().exclude(allow_self_registration=False)
-    # invalidate cache for every open communities, unless that if /open-communities/ is loaded before /communities/xyz/, the last one will get wrong permission nodes
-    from djangoldp.serializers import LDListMixin, LDPSerializer
-    LDListMixin.to_representation_cache.reset()
-    for result in queryset:
-      if(result.urlid):
-        LDPSerializer.to_representation_cache.invalidate(result.urlid)
+
+    # invalidate cache for every open communities
+    # unless /open-communities/ is loaded before /communities/xyz/, the last one will get wrong permission nodes
+    from djangoldp.serializers import invalidate_model_cache_if_has_entry
+    invalidate_model_cache_if_has_entry(self.model)
+
     return queryset
